{ inputs, config, pkgs, ... }:

{
  imports = [
    (import ./common.nix { inherit inputs config pkgs; })
    (import ./hyprland { inherit inputs pkgs; })
    (import ./waybar { inherit inputs pkgs; })
    ./rofi
    ./alacritty
    ./kitty
    ./firefox
    ./ssh
    ./mpv
  ];
  home.packages = with pkgs; [ telegram-desktop webcord devenv ];
  programs.ssh.matchBlocks."*".identityFile = "/home/server/.secrets/SSH/Aloria/id_ed25519";

  services.hyprpaper = {
    settings = {
      wallpaper = [
        "HDMI-A-1,${./hyprland/files/wallpaper.png}"
        "HDMI-A-2,${./hyprland/files/wallpaper.png}"
        "eDP-1,${./hyprland/files/wallpaper.png}"
      ];
    };
  };

  gtk.iconTheme = {
    name = "Papirus";
    gtk.iconTheme.package = pkgs.papirus-icon-theme;
  };

  # wayland.windowManager.hyprland.settings.env = ["WLR_DRM_DEVICES,/dev/dri/by-path/pci-0000:01:00.0-card"]; # Nvidia
  wayland.windowManager.hyprland.settings.env = ["WLR_DRM_DEVICES,/dev/dri/by-path/pci-0000:00:02.0-card"]; # Intel
  wayland.windowManager.hyprland.settings = {
      monitor = [
          "eDP-1,1920x1080@144,0x0,1"
          "HDMI-A-2,1920x1080@60,0x-1080,1"
      ];
      bind = [
        ", XF86PowerOff, exec, ${pkgs.rofi}/bin/rofi -show power-menu -modi power-menu:${
          ./hyprland/files/rofi-power-menu.sh
        }"
      ];
      general.gaps_out = 1;
  };
  programs.waybar.settings.mainBar = {
      output = "eDP-1";
      height = 28;
      margin = "0 0 5 0";
  };

  programs.alacritty.settings.font.size = 13;
}
