{ pkgs, ... }:

{
  services.pcscd.enable = true;
  services.udev.packages = [ pkgs.yubikey-personalization ];

  # Calendar
  programs.dconf.enable = true;
  services.gnome.evolution-data-server.enable = true;
  services.gnome.gnome-online-accounts.enable = true;
  services.gnome.gnome-keyring.enable = true;
  environment.systemPackages = with pkgs; [ wireguard-tools ];

  # Add the server using gnome-online-accounts:
  # nix-shell -p gnome.gnome-control-center --run "gnome-control-center"
  # Just add the main webdav server and gnome-calendar will automatically pick up all available calendars.

  networking.wg-quick.interfaces = {
    wg0 = {
      address = [ "10.0.0.5/24" "2a02:a03f:83ad:2101::5/128" ];
      dns = [ "10.0.0.1" "fdc9:281f:04d7:9ee9::1" ];
      privateKeyFile = "/home/user/.secrets/Wireguard/Aloria.key";
      listenPort = 51820;
      postUp = "resolvectl dns %i 10.0.0.1; resolvectl domain %i ~thomasave.be;";
      peers = [{
        publicKey = "/9ppjm3yeD0duDvxrqgcHscHmftXko+0s2RbivNEy2c=";
        allowedIPs = [ "10.0.0.1/8"  "192.168.1.2/32" ];
        endpoint = "h.thomasave.be:13231";
        persistentKeepalive = 25;
      }];
    };
  };
  fileSystems."/home/server" = {
    device = "10.1:/home/server";
    fsType = "nfs";
    options = [ "x-systemd.automount" "noauto" ];
  };
  fileSystems."/home/user/Workspace" = {
    device = "10.1:/home/server/Workspace";
    fsType = "nfs";
    options = [ "x-systemd.automount" "noauto" ];
  };
  fileSystems."/home/user/Documents" = {
    device = "10.1:/home/server/Storage/Thomas/Documents";
    fsType = "nfs";
    options = [ "x-systemd.automount" "noauto" ];
  };
  fileSystems."/home/user/Pictures" = {
    device = "10.1:/home/server/Storage/Thomas/Pictures";
    fsType = "nfs";
    options = [ "x-systemd.automount" "noauto" ];
  };
  fileSystems."/home/user/Videos" = {
    device = "10.1:/home/server/Storage/Thomas/Videos";
    fsType = "nfs";
    options = [ "x-systemd.automount" "noauto" ];
  };
}
